import os
import os.path
import re
import sys
import datetime

from django import template
from rest_framework.authtoken.models import Token
from galeria.settings import FORCE_SCRIPT_NAME

register = template.Library()

PATTERN = re.compile(r'page=(\d+)')

def _calc_page(value, func):
    t = PATTERN.search(value)
    if t is None:
        if '?' in value:
            return value + '&page=2'
        return value + '?&page=2'
    m = t.group()
    num = int(m.split('=')[1])
    return value.replace(m, 'page=%d' % func(num))

@register.filter(name='prev_page')
def prev_page(value):
    return _calc_page(value, lambda n: n-1)

@register.filter(name='next_page')
def next_page(value):
    return _calc_page(value, lambda n: n+1)

@register.filter(name='range')
def _range(min=1,max=5):
    return range(min,max+1)

@register.filter(name='get_cover')
def get_cover(photo, user):
    if not photo.private or user.is_authenticated:
        return photo
    for p in photo.the_album.get_photos():
        if not p.private:
            return p
    message = _('This should not be possible: %(photo)s' % { 'photo': photo })
    raise ValueError(message)

@register.filter(name='get_the_path')
def get_the_path(photo, results):
    if results:
        return photo.url[1:]
    return photo.basename

@register.filter(name='get_thumb_url')
def get_thumb_url(photo, user):
    if photo.private and user.is_authenticated:
        token = Token.objects.get_or_create(user=user)[0]
        return '%s?token=%s' % (FORCE_SCRIPT_NAME + photo.thumb_url, token.key)
    return FORCE_SCRIPT_NAME + photo.thumb_url

@register.filter(name='get_url')
def get_url(photo, user):
    if photo.private and user.is_authenticated:
        token = Token.objects.get_or_create(user=user)[0]
        return '%s?token=%s' % (FORCE_SCRIPT_NAME + photo.url, token.key)
    return FORCE_SCRIPT_NAME + photo.url

@register.filter(name='get_view_url')
def get_view_url(photo, user):
    if photo.private and user.is_authenticated:
        token = Token.objects.get_or_create(user=user)[0]
        return '%s?token=%s' % (FORCE_SCRIPT_NAME + photo.view_url, token.key)
    return FORCE_SCRIPT_NAME + photo.view_url

@register.filter(name='comment_return')
def comment_return(value):
    if value.endswith('.jpg'):
        return value + '?moderation=true'
    if '.jpg?' in value:
        i = value.index('.jpg?') + 5
        get = value[i:-1]
        parms = get.split('&')
        newparms = ''
        for parm in parms:
            if '=' not in parm:
                newparms += (parm + '&')
                continue
            t = parm.split('=')
            if t == 'moderation' or t == 'c':
                continue
            newparms += (parm + '&')
        newparms = newparms[:-1]
        return value[:i] + newparms
    return value + '&moderation=true'
